Mixed-Up Code Exercises
-----------------------

Answer the following **Mixed-Up Code** or **Activecode** questions to
assess what you have learned in this chapter.

.. selectquestion:: mucp_14_1_sq
   :fromid: mucp_14_1, mucp_14_1_ac_q
   :toggle:

.. selectquestion:: mucp_14_2_sq
   :fromid: mucp_14_2, mucp_14_2_ac_q
   :toggle:

.. selectquestion:: mucp_14_3_sq
   :fromid: mucp_14_3, mucp_14_3_ac_q
   :toggle:

.. selectquestion:: mucp_14_4_sq
   :fromid: mucp_14_4, mucp_14_4_ac_q
   :toggle:

.. selectquestion:: mucp_14_5_sq
   :fromid: mucp_14_5, mucp_14_5_ac_q
   :toggle:

.. selectquestion:: mucp_14_6_sq
   :fromid: mucp_14_6, mucp_14_6_ac_q
   :toggle:

.. selectquestion:: mucp_14_7_sq
   :fromid: mucp_14_7, mucp_14_7_ac_q
   :toggle:

.. selectquestion:: mucp_14_8_sq
   :fromid: mucp_14_8, mucp_14_8_ac_q
   :toggle:

.. selectquestion:: mucp_14_9_sq
   :fromid: mucp_14_9, mucp_14_9_ac_q
   :toggle:

.. selectquestion:: mucp_14_10_sq
   :fromid: mucp_14_10, mucp_14_10_ac_q
   :toggle:
